<?php
    define ('LGMAX', 200);       // longueur maximale des lignes des fichiers


    // fabrique un menu déroulant avec la liste des langues disponibles

    function gen_langues_dispo ($langue_choisie, $niveau, $lg_util)
    {
        // fichier liste des langues autorisées
        $ficliste = DIRLANGUES."/dispo-langues_".$niveau."_".$lg_util;

        // si la liste cherchée n'existe pas
        if (! file_exists ($ficliste))
        {
            // erreur fatale
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", basename ($ficliste));
            echo "</option>\n";
            return;
        }

        // si aucune langue n'a été sélectionnée
        if ($langue_choisie == "")
            // mettre un choix vierge en début de liste
            echo "            <option selected value=\"\"></option>\n";

        // ouvrir le fichier contenant la liste des langues disponibles
        $descfic = fopen ($ficliste, "r");

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // récupérer le code de la langue et son nom
            $separation = strpos ($ligne, " ");
            $code_lg = substr ($ligne, 0, $separation);
            $langue = substr ($ligne, $separation + 1);

            // générer une ligne du menu déroulant
            echo "            <option ";

            // si on est arrivé à la langue choisie
            if ($code_lg == $langue_choisie)
                // la sélectionner
                echo "selected ";

            // fin de la génération de la ligne
            echo "value=\"".$code_lg."\">".$langue."</option>\n";

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);
    }



    // fabrique un menu déroulant avec la liste des langues cibles
    // disponibles pour une traduction directe depuis la langue source

    function gen_lg_cible_traddir ($langue_source, $langue_cible, $niveau, $lg_util)
    {
        $ficsenstrad = DIRLANGUES."/senstrad_".$niveau;
        $ficliste = DIRLANGUES."/dispo-langues_".$niveau."_".$lg_util;

        // première étape : extraire les langues cibles disponibles en traduction directe
        // si la liste des sens de traduction n'existe pas
        if (! file_exists ($ficsenstrad))
        {
            // erreur fatale
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", basename ($ficsenstrad));
            echo "</option>\n";
            return;
        }

        // ouvrir le fichier contenant la liste des sens de traduction
        $descfic = fopen ($ficsenstrad, "r");

        // initialisation
        $listelangues = "";

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // récupérer le code de la langue source
            $separation = strpos ($ligne, " ");
            $code_lg_source = substr ($ligne, 0, $separation);

            // si c'est la langue source déjà sélectionnée
            if ($code_lg_source == $langue_source)
            {
                // fin éventuelle du champ code_lg_cible
                $dersep = strrpos ($ligne, " ");

                // si la ligne comporte aussi un sens de traduction
                if ($dersep > $separation)
                    // l'enlever
                    $ligne = substr ($ligne, 0, $dersep);

                // récupérer le code de la langue cible
                $code_lg_cible = substr ($ligne, $separation + 1);

                // l'ajouter dans la liste des langues cibles possibles
                $listelangues = $listelangues." ".$code_lg_cible." ";
            }

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);

        // deuxième étape : générer le menu déroulant

        // si la liste cherchée n'existe pas
        if (! file_exists ($ficliste))
        {
            // erreur fatale
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", basename ($ficliste));
            echo "</option>\n";
            return;
        }

        // si aucune langue cible n'a été sélectionnée
        // ou la langue source vient d'être changée
        // avec 2 modes de détection du dernier test
        if ($langue_cible == "")
            $champvierge = 1;
        else if ($niveau == "l")
        {
            // test pour une traduction de lemme
            if ($langue_source != $_POST ['srcprec'])
                $champvierge = 1;
        }
        // test pour une traduction de texte ou de page web
        else if ($langue_source != $_COOKIE ['lg_source'])
            $champvierge = 1;

        if ($champvierge)
            // mettre un choix vierge en début de liste
            echo "            <option value=\"\"></option>\n";

        // initialisation
        $lg_cible_acceptee = 0;

        // ouvrir le fichier contenant la liste des langues disponibles
        $descfic = fopen ($ficliste, "r");

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // récupérer le code de la langue
            $separation = strpos ($ligne, " ");
            $code_lg = substr ($ligne, 0, $separation);

            // si cette langue est accessible en traduction directe
            if (strpos ($listelangues, $code_lg) > 0)
            {
                // récupérer le nom de la langue
                $langue = substr ($ligne, $separation + 1);

                // générer une ligne du menu déroulant
                echo "            <option ";

                // si on est arrivé à la langue choisie
                if ($code_lg == $langue_cible)
                {
                    // la sélectionner
                    echo "selected ";

                    // et mémoriser le fait qu'on l'a trouvée
                    $lg_cible_acceptee = 1;
                }

                // fin de la génération de la ligne
                echo "value=\"".$code_lg."\">".$langue."</option>\n";
            }

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);

        // si la langue cible choisi n'est pas accessible en traduction directe
        if (! $lg_cible_acceptee)
            // désélectionner cette langue
            setcookie ("lg_cible", "", 0);
    }



    // fabrique un menu déroulant avec la liste des langues intermédiaires
    // disponibles pour une traduction directe ou en 2 étapes

    function gen_lg_pivot ($langue_source, $langue_cible, $langue_pivot, $niv, $lg_util)
    {
        $ficsenstrad = DIRLANGUES."/senstrad_".$niv;
        $ficliste = DIRLANGUES."/dispo-langues_".$niv."_".$lg_util;

        // première étape : extraire les langues cibles disponibles en traduction directe
        // si la liste des sens de traduction n'existe pas
        if (! file_exists ($ficsenstrad))
        {
            // erreur fatale
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", basename ($ficsenstrad));
            echo "</option>\n";
            return;
        }

        // ouvrir le fichier contenant la liste des sens de traduction
        $descfic = fopen ($ficsenstrad, "r");

        // initialisation
        $liste_cible  = "";
        $liste_source = "";

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // extraire les codes de la langue source et de la langue cible
            $separation = strpos ($ligne, " ");
            $code_lg_source = substr ($ligne, 0, $separation);
            $ligne = trim (substr ($ligne, $separation + 1));
            $separation = strpos ($ligne, " ");
            $code_lg_cible = substr ($ligne, 0, $separation);

            // mémoriser les possibilités de traduction depuis la langue source
            if ($code_lg_source == $langue_source)
            {
                // si on est tombé sur une possibilité de traduction directe
                if ($code_lg_cible == $langue_cible && ! isset ($premier))
                {
                    // générer cette possibilité dans le menu déroulant
                    echo "            <option value=\"direct\">";
                    echo message ("TRAD_DIR");  // traduction directe
                    echo "</option>\n";

                    // ce sera le choix par défaut si un autre n'a pas été choisi
                    $premier = "direct";
                }
                // sinon
                else
                    // l'ajouter dans la liste des langues intermédiaires possibles
                    $liste_cible = $liste_cible." ".$code_lg_cible." ";
            }
            // mémoriser les possibilités de traduction indirectes vers la langue cible
            else if ($code_lg_cible == $langue_cible)
                $liste_source = $liste_source." ".$code_lg_source." ";

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);

        // deuxième étape : générer le menu déroulant

        // si la liste cherchée n'existe pas
        if (! file_exists ($ficliste))
        {
            // erreur fatale
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", basename ($ficliste));
            echo "</option>\n";
            return;
        }

        // si pas de possibilité de traduction directe
        if (! isset ($premier))
        {
            // si aucune langue pivot n'a été sélectionnée
            // ou la langue source ou cible vient d'être changée
            if ($langue_pivot == "" || ($langue_source != $_COOKIE ['lg_source'])
                                    || ($langue_cible  != $_COOKIE ['lg_cible']))
                // mettre un choix vierge en début de liste
                echo "            <option value=\"\"></option>\n";
        }

        // initialisation
        $lg_pivot_acceptee = 0;

        // ouvrir le fichier contenant la liste des langues disponibles
        $descfic = fopen ($ficliste, "r");

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // récupérer le code de la langue
            $separation = strpos ($ligne, " ");
            $code_lg = substr ($ligne, 0, $separation);

            // si cette langue est possible comme langue de traduction intermédiaire
            if (strpos ($liste_cible, $code_lg) > 0 && strpos ($liste_source, $code_lg) > 0)
            {
                // la mémoriser si c'est la première de la liste
                if (! isset ($premier))
                    $premier = $code_lg;

                // récupérer le nom de la langue
                $langue = substr ($ligne, $separation + 1);

                // générer une ligne du menu déroulant
                echo "            <option ";

                // si cette langue pivot a déjà été choisie
                if ($code_lg == $langue_pivot)
                {
                    // la sélectionner
                    echo "selected ";

                    // et mémoriser le fait qu'on l'a trouvée
                    $lg_pivot_acceptee = 1;
                }

                // fin de la génération de la ligne
                echo "value=\"".$code_lg."\">".$langue."</option>\n";
            }

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);

        // si on n'a pas conservé la langue intermédiaire précédemment choisie
        if (! $lg_pivot_acceptee)
        {
            // sélectionner si possible le premier choix du menu déroulant
            if (isset ($premier))
                setcookie ("lg_pivot", $premier, 0);
            // sinon, pas de possibilité de traduction
            else
                setcookie ("lg_pivot", "", 0);
        }
    }



    // fabrique un menu déroulant avec la liste des
    // paires de langues disponibles pour une langue donnée

    function gen_liste_paires ($langue, $lgprec, $paire)
    {
        $ficpaires = DIRLANGUES."/paires_a";

        // si la liste des paires de langues n'existe pas
        if (! file_exists ($ficpaires))
        {
            // erreur rendant inutile l'exploration de ce fichier
            echo "            <option selected value=\"\">";
            echo msg_chaine ("MANQUE_FICH", "paires_a");
            echo "</option>\n";
            return;
        }

        // si la langue vient d'être changée
        // ou aucune paire n'a été sélectionnée
        if ($langue != $lgprec || $paire == "")
            // mettre un choix vierge en début de liste
            echo "            <option selected value=\"\"></option>\n";

        // ouvrir le fichier contenant la liste des paires de langues
        $descfic = fopen ($ficpaires, "r");

        // lire la première ligne
        $ligne = trim (fgets ($descfic, LGMAX));

        // tant que non fin de fichier
        while ($ligne)
        {
            // récupérer les deux codes de langue de la paire
            $separation = strpos ($ligne, " ");
            $code_lg = substr ($ligne, 0, $separation);

            // si l'une des langues de la paire est celle recherchée
            if ($langue == $code_lg)
            {
                 // récupérer le nom de la paire
                $paire_lue = trim (substr ($ligne, $separation + 1));
                $nom_paire = substr ($paire_lue, 0, strpos ($paire_lue, "/"));

                // générer une ligne du menu déroulant
                echo "            <option ";

                // si on est arrivé à la paire déjà choisie
                if ($paire_lue == $paire)
                    // la sélectionner
                    echo "selected ";

                // fin de la génération de la ligne
                echo "value=\"".$paire_lue."\">".$nom_paire."</option>\n";
            }

            // lire la ligne suivante
            $ligne = trim (fgets ($descfic, LGMAX));
        }

        // terminé avec ce fichier
        fclose ($descfic);
    }



    // fabrique une entrée du menu déroulant des formats du texte

    function gen_entree_format ($code_format, $message, $format_choisi)
    {
        echo "            <option ";

        // si on est arrivé à la paire déjà choisie
        if ($code_format == $format_choisi)
            // la sélectionner
            echo "selected ";

        // fin de la génération de la ligne
        echo "value=\"".$code_format."\">".$message."</option>\n";
    }



    // fabrique un menu déroulant avec la liste des formats du texte

    function gen_formats_texte ($format_choisi)
    {
        gen_entree_format ("txt",   message ("TEXTE_BRUT"), $format_choisi);
        gen_entree_format ("html",  "HTML",  $format_choisi);
        gen_entree_format ("latex", "Latex", $format_choisi);
        gen_entree_format ("man",   message ("PAGE_MAN"),   $format_choisi);
        gen_entree_format ("mnemo", message ("FICH_MNEMO"), $format_choisi);
        gen_entree_format ("rtf",   "RTF",   $format_choisi);
        gen_entree_format ("mediawiki", message ("PAGE_WIKI"), $format_choisi);
    }
?>
