<?php
    // Constantes
    require ("dirsite.php");

    define ('LGMAX_MESS', 100);  // longueur maximale des lignes des fichiers message


    // fonction qui remplace un code de langue sur 2
    // caractères par son équivalent sur 3 caractères

    function majcode2car ($code)
    {
        // variables statiques pour ne mémoriser qu'une fois la table des codes
        static $codes = array();
        static $charge = 0;

        // si on n'a pas encore mémorisé la signification des codes possibles
        if (! $charge)
        {
            // sélectionner le fichier qui les contient
            $fic_codes = CORESP_CODES;

            // si le fichier des codes existe
            if (file_exists ($fic_codes))
            {
                // l'ouvrir en lecture
                $descfic = fopen ($fic_codes, "r");

                // lire la première ligne de ce fichier
                $ligne = fgets ($descfic, 15);

                // tant que non fin de fichier
                while ($ligne)
                {
                    // extraire le code de 2 caractères
                    $code2car = substr ($ligne, 0, 2);

                    // mémoriser le code correspondant dans le tableau associatif
                    $codes [$code2car] = trim (substr ($ligne, 3));

                    // passer à la ligne suivante
                    $ligne = fgets ($descfic, 15);
                }

                // terminé avec ce fichier
                fclose ($descfic);
            }

            // on n'aura pas besoin de le lire une autre fois
            $charge ++;
        }

        // si code mémorisé
        if (isset ($codes [$code]))
            // le renvoyer
            return $codes [$code];
        // sinon
        else
            // renvoyer le code inchangé
            return $code;
    }


    // choix d'une langue parmi les préférences du navigateur

    function choix_langue_navigateur ()
    {
        // récupérer la liste des langues préférées par le navigateur
        $langues = str_replace (";", ",", $_SERVER['HTTP_ACCEPT_LANGUAGE']);

        // tant qu'il reste des langues à tester
        while ($langues)
        {
            // chercher le séparateur vers la langue suivante
            $posvirg = strpos ($langues, ",");

            // si séparateur trouvé
            if ($posvirg)
            {
                // extraire la langue
                $lg_test = substr ($langues, 0, $posvirg);

                // et conserver ce qui suit
                $langues = substr ($langues, $posvirg + 1);
            }
            // sinon
            else
            {
                // il reste juste une langue
                $lg_test = $langues;
                $langues = "";
            }

            // si la langue comporte un -
            if (strpos ($lg_test, "-") > 0)
                // prendre juste la partie de gauche
                $lg_test = substr ($lg_test, 0, strpos ($lg_test, "-"));

            // si code sur 2 caractères
            if (strlen ($lg_test) == 2)
                // choisir le code de 3 caractères équivalent
                $lg_test = majcode2car ($lg_test);

            // si la langue est supportée
            if (file_exists (DIRMSG."/".$lg_test))
                // choisir cette langue
                return $lg_test;
        }

        // sinon langue par défaut (il en faut une)
        return ("fra");
    }



    // choix de la langue de l'interface utilisateur

    function choix_langue ()
    {
        // si langue passée en paramètre par la méthode get
        if (isset ($_GET ['lang']))
        {
            $langue = $_GET ['lang'];

            // si code sur 2 caractères
            if (strlen ($langue) == 2)
                // choisir le code de 3 caractères équivalent
                $langue = majcode2car ($langue);

            // la mémoriser dans un cookie
            setcookie ("lg_util", $langue, 0);

            // et retourner cette langue
            return $langue;
        }
        // sinon un cookie mémorise la langue de l'interface utilisateur
        else if (isset ($_COOKIE ['lg_util']))
            // retourner cette langue
            return $_COOKIE ['lg_util'];
        // sinon
        else
        {
            // choisir dans la liste des langues préférées par le navigateur
            $langue = choix_langue_navigateur ();

            // la mémoriser dans un cookie
            setcookie ("lg_util", $langue, 0);

            // et retourner cette langue
            return ($langue);
        }
    }


    // fonction qui trouve la signification d'un mnémonique
    // dans la langue de l'interface utilisateur

    function message ($mnemonique)
    {
        // variables statiques pour ne mémoriser qu'une fois la table des messages
        static $message = array();
        static $charge = 0;

        // si on n'a pas encore mémorisé la signification des messages possibles
        if (! $charge)
        {
            // sélectionner le fichier qui les contient
            $ficmsg = DIRMSG."/".choix_langue ();

            // si le fichier des messages n'existe pas dans la langue
            if (! file_exists ($ficmsg))
            {
                // erreur fatale
                return "Fichier mnémonique manquant";
            }

            // ouvrir en lecture le fichier des messages
            $descfic = fopen ($ficmsg, "r");

            // lire la première ligne de ce fichier
            $ligne = fgets ($descfic, LGMAX_MESS);

            // tant que non fin de fichier
            while ($ligne)
            {
                // chercher la position de la fin du mnémonique
                $posblanc = strpos ($ligne, " ");

                // récupérer le mnémonique
                $mnemo = substr ($ligne, 0, $posblanc);

                // récupérer le message correspondant
                $mess = trim (substr ($ligne, $posblanc + 1));

                // mémoriser l'information dans le tableau associatif
                $message [$mnemo] = $mess;

                // passer à la ligne suivante
                $ligne = fgets ($descfic, LGMAX_MESS);
            }

            // terminé avec ce fichier
            fclose ($descfic);

            // on n'aura pas besoin de le lire une autre fois
            $charge ++;
        }

        // si message mémorisé
        if (isset ($message [$mnemonique]))
            // le renvoyer
            return $message [$mnemonique];
        // sinon
        else
            // renvoyer un message d'erreur
            return "??".$mnemonique."??";
    }


    // fonction qui retourne un message comportant la chaine
    // passée en paramètre dans la langue de l'utilisateur

    function msg_chaine ($mnemonique, $chaine)
    {
        // récupérer le message correspondant au mnémonique
        $message = message ($mnemonique);

        // remplacer %s par la chaine et retourner le résultat
        return str_replace ("%s", $chaine, $message);
    }


    // fonction qui remplace un mnémonique par sa signification
    // dans la langue de l'interface utilisateur

    function majmessage (& $ligne)
    {
        // extraire la partie de la ligne qui commence par MM_
        $finligne = trim (substr ($ligne, strpos ($ligne, "MM_")));

        // chercher la position de la fin du mnémonique
        if (strpos ($finligne, "&nbsp;"))
            $fin_mnemo = strpos ($finligne, "&nbsp;");
        else
            $fin_mnemo = strpos ($finligne, " ");

        if (! $fin_mnemo)
            $fin_mnemo = strpos ($finligne, "<");

        // si caractère trouvé après le mnémonique
        if ($fin_mnemo)
            // extraire le mnémonique
            $mnemo_mmm = substr ($finligne, 0, $fin_mnemo);
        // sinon
        else
            // a avait déjà le mémonique
            $mnemo_mmm = $finligne;

        // enlever le MM_ du mnémonique et l'éventuel espace à la fin
        $mnemo = rtrim (substr ($mnemo_mmm, 3));

        // remplacer dans la ligne le mnémonique (avec mmm) par sa signification
        $ligne = str_replace ($mnemo_mmm, message ($mnemo), $ligne);
    }
?>
